%define tarname	ScientificPython

Summary: 	Various Python modules for scientific computing
Name: 		python-scientific
Version: 	2.9.4
Release: 	%mkrel 4
Source: 	https://sourcesup.renater.fr/frs/download.php/file/4570/%{tarname}-%{version}.tar.gz
Patch0:		setup.py.patch
Patch1:		remove_oldnumeric.patch
License: 	CeCILL-C
Group: 		Development/Python
Url: 		http://dirac.cnrs-orleans.fr/ScientificPython/
BuildRequires: 	pkgconfig(netcdf)
BuildRequires:	python-numpy-devel
BuildRequires:	pkgconfig(ompi)
BuildRequires:	openmpi
BuildRequires:	pkgconfig(python)
Requires:	python-numpy
Requires:	openmpi

%description
ScientificPython is a collection of Python modules that are useful for
scientific computing. In this collection you will find modules that
cover basic geometry (vectors, tensors, transformations, vector and
tensor fields), quaternions, automatic derivatives, (linear)
interpolation, polynomials, elementary statistics, nonlinear
least-squares fits, unit calculations, Fortran-compatible text
formatting, 3D visualization via VRML, and two Tk widgets for simple
line plots and 3D wireframe models. There are also interfaces to the
netCDF library (portable structured binary files), to MPI (Message
Passing Interface, message-based parallel programming), and to BSPlib
(Bulk Synchronous Parallel programming).

%package devel
Summary:	Various Python modules for scientific computing, header files
Group: 		Development/Python
Requires: 	python-devel %{name} = %{version}

%description devel
This package contain headers file associated with the %{name} package.

%prep
%setup -q -n %{tarname}-%{version}
%patch0 -p0
%patch1 -p0

# fix encoding
iconv -f ISO-8859-1 -t UTF-8 LICENSE -o LICENSE-utf8
touch -r LICENSE LICENSE-utf8
mv LICENSE-utf8 LICENSE

%build
%py2_build

%install
%py2_install

export PYTHONPATH=%{buildroot}%{python2_sitearch}
export PYINCLUDE=`pwd`/Include
pushd Src/MPI
%ifarch x86_64
sed -i 's/lib\/python/lib64\/python/' compile.py
%endif
cat compile.py | sed 's/-I/-I$PYINCLUDE -I/' > compile-new.py
%{__python2} compile-new.py

%__install -m 755 mpipython %{buildroot}%{_bindir}

cat <<EOF>impipython
#!/bin/bash
mpirun -np 2 `python -c "from distutils.sysconfig import get_python_lib; print get_python_lib(1)+'/Scientific/BSP/console.py'"` $*
EOF

popd


%files
%doc LICENSE README README.MPI README.BSP Doc/CHANGELOG Doc/Reference Doc/BSP_Tutorial.pdf Examples/ Src/MPI/impipython
%{python2_sitearch}/Scientific/*
%{python2_sitearch}/*.egg-info
%defattr(755,root,root)
%{_bindir}/*

%files devel
%{_includedir}/python%{python2_version}/Scientific/


%changelog
* Fri Dec 02 2016 tmb <tmb> 2.9.4-4.mga6
+ Revision: 1071633
- rebuild for new openmpi

* Tue Feb 16 2016 umeabot <umeabot> 2.9.4-3.mga6
+ Revision: 962443
- Mageia 6 Mass Rebuild

* Wed Sep 30 2015 daviddavid <daviddavid> 2.9.4-2.mga6
+ Revision: 885280
- rebuild for new openmpi 1.10.0
- use new python2 macros

* Sat Jul 25 2015 philippem <philippem> 2.9.4-1.mga6
+ Revision: 857664
- update to 2.9.4, fix build
- update to 2.9.4

* Wed Oct 15 2014 umeabot <umeabot> 2.9.3-5.mga5
+ Revision: 746211
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 2.9.3-4.mga5
+ Revision: 729706
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 2.9.3-3.mga5
+ Revision: 688317
- Mageia 5 Mass Rebuild

  + pterjan <pterjan>
    - Rebuild for new Python

* Sat Mar 08 2014 philippem <philippem> 2.9.3-1.mga5
+ Revision: 601300
- Update to 2.9.3

* Tue Oct 22 2013 umeabot <umeabot> 2.9.2-3.mga4
+ Revision: 544226
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 pterjan <pterjan> 2.9.2-2.mga4
+ Revision: 499326
- Rebuild to add different pythonegg provides for python 2 and 3

* Thu Jul 04 2013 philippem <philippem> 2.9.2-1.mga4
+ Revision: 450065
- Update to 2.9.2

* Sun Jan 13 2013 umeabot <umeabot> 2.8-10.mga3
+ Revision: 379465
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Jun 14 2012 eatdirt <eatdirt> 2.8-9.mga3
+ Revision: 260545
- Rebuild for openmpi-1.6

* Fri Jan 13 2012 eatdirt <eatdirt> 2.8-8.mga3
+ Revision: 195648
- Rebuild against openmpi-1.4.4

  + fwang <fwang>
    - rebuild for new netcdf

* Tue Jun 28 2011 ahmad <ahmad> 2.8-6.mga2
+ Revision: 115368
- Drop the buildroot declaration
- Fix the encoding of the LICENSE file
- imported package python-scientific


* Sat Nov 06 2010 Funda Wang <fwang@mandriva.org> 2.8-5mdv2011.0
+ Revision: 593993
- rebuild for py2.7

* Thu Feb 18 2010 Emmanuel Andry <eandry@mandriva.org> 2.8-4mdv2010.1
+ Revision: 507529
- rebuild for new netcdf

* Wed Aug 12 2009 Funda Wang <fwang@mandriva.org> 2.8-3mdv2010.0
+ Revision: 415365
- rebuild for new libtorque

* Thu Mar 19 2009 Lev Givon <lev@mandriva.org> 2.8-2mdv2009.1
+ Revision: 358154
- Fix bug 48269.

* Wed Mar 18 2009 Lev Givon <lev@mandriva.org> 2.8-1mdv2009.1
+ Revision: 357437
- Update to 2.8.

* Fri Jan 02 2009 Funda Wang <fwang@mandriva.org> 2.6.1-4mdv2009.1
+ Revision: 323326
- fix file list

* Fri Aug 01 2008 Thierry Vignaud <tv@mandriva.org> 2.6.1-4mdv2009.0
+ Revision: 259777
- rebuild

* Fri Jul 25 2008 Thierry Vignaud <tv@mandriva.org> 2.6.1-3mdv2009.0
+ Revision: 247631
- rebuild

* Fri Dec 21 2007 Olivier Blin <oblin@mandriva.com> 2.6.1-1mdv2008.1
+ Revision: 136460
- restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

  + Lev Givon <lev@mandriva.org>
    - Update to 2.6.1.


* Tue Feb 20 2007 Lev Givon <lev@mandriva.org> 2.6-1mdv2007.0
+ Revision: 123082
- Update to latest stable release 2.6.
  Add python-numeric install dependency.

* Tue Dec 05 2006 Nicolas Lécureuil <neoclust@mandriva.org> 2.4.9-6mdv2007.1
+ Revision: 90634
- Rebuild against new Python
- import python-scientific-2.4.9-5mdk

* Wed Dec 21 2005 Michael Scherer <misc@mandriva.org> 2.4.9-5mdk
- Fix BuildRequires
- fix rpmbuildupdatability

* Tue Dec 20 2005 Michael Scherer <misc@mandriva.org> 2.4.9-4mdk
- fix BuildRequires

* Tue Jun 21 2005 Lehmann Gatan <gaetan.lehmann@jouy.inra.fr> 2.4.9-3mdk
- buildrequires netcdf-devel
- use mkrel
- fix some lint

* Thu Feb 03 2005 Michael Scherer <misc@mandrake.org> 2.4.9-2mdk
- add BuildRequires

* Mon Nov 29 2004 Gaetan Lehmann <gaetan.lehmann@jouy.inra.fr> 2.4.9-1mdk
- initial contrib release.

